summaryrefslogtreecommitdiff
path: root/docs/quick_tour
diff options
context:
space:
mode:
Diffstat (limited to 'docs/quick_tour')
-rw-r--r--docs/quick_tour/logging/hello_world/static/theme.css3
-rw-r--r--docs/quick_tour/logging/setup.py4
-rw-r--r--docs/quick_tour/package/hello_world/static/theme.css3
-rw-r--r--docs/quick_tour/package/setup.py4
-rw-r--r--docs/quick_tour/sessions/hello_world/static/theme.css3
-rw-r--r--docs/quick_tour/sessions/setup.py4
-rw-r--r--docs/quick_tour/sqla_demo/setup.py4
-rw-r--r--docs/quick_tour/sqla_demo/sqla_demo/models/meta.py2
-rw-r--r--docs/quick_tour/sqla_demo/sqla_demo/static/theme.css3
-rw-r--r--docs/quick_tour/views/views.py4
10 files changed, 23 insertions, 11 deletions
diff --git a/docs/quick_tour/logging/hello_world/static/theme.css b/docs/quick_tour/logging/hello_world/static/theme.css
index 0f4b1a4d4..a70ee557a 100644
--- a/docs/quick_tour/logging/hello_world/static/theme.css
+++ b/docs/quick_tour/logging/hello_world/static/theme.css
@@ -17,6 +17,9 @@ h6 {
p {
font-weight: 300;
}
+button, input, optgroup, select, textarea {
+ color: black;
+}
.font-normal {
font-weight: 400;
}
diff --git a/docs/quick_tour/logging/setup.py b/docs/quick_tour/logging/setup.py
index 27b025384..e9c15db04 100644
--- a/docs/quick_tour/logging/setup.py
+++ b/docs/quick_tour/logging/setup.py
@@ -17,8 +17,8 @@ requires = [
]
tests_require = [
- 'WebTest >= 1.3.1', # py3 compat
- 'pytest>=3.7.4',
+ 'WebTest',
+ 'pytest',
'pytest-cov',
]
diff --git a/docs/quick_tour/package/hello_world/static/theme.css b/docs/quick_tour/package/hello_world/static/theme.css
index 0f4b1a4d4..a70ee557a 100644
--- a/docs/quick_tour/package/hello_world/static/theme.css
+++ b/docs/quick_tour/package/hello_world/static/theme.css
@@ -17,6 +17,9 @@ h6 {
p {
font-weight: 300;
}
+button, input, optgroup, select, textarea {
+ color: black;
+}
.font-normal {
font-weight: 400;
}
diff --git a/docs/quick_tour/package/setup.py b/docs/quick_tour/package/setup.py
index 27b025384..e9c15db04 100644
--- a/docs/quick_tour/package/setup.py
+++ b/docs/quick_tour/package/setup.py
@@ -17,8 +17,8 @@ requires = [
]
tests_require = [
- 'WebTest >= 1.3.1', # py3 compat
- 'pytest>=3.7.4',
+ 'WebTest',
+ 'pytest',
'pytest-cov',
]
diff --git a/docs/quick_tour/sessions/hello_world/static/theme.css b/docs/quick_tour/sessions/hello_world/static/theme.css
index 0f4b1a4d4..a70ee557a 100644
--- a/docs/quick_tour/sessions/hello_world/static/theme.css
+++ b/docs/quick_tour/sessions/hello_world/static/theme.css
@@ -17,6 +17,9 @@ h6 {
p {
font-weight: 300;
}
+button, input, optgroup, select, textarea {
+ color: black;
+}
.font-normal {
font-weight: 400;
}
diff --git a/docs/quick_tour/sessions/setup.py b/docs/quick_tour/sessions/setup.py
index 27b025384..e9c15db04 100644
--- a/docs/quick_tour/sessions/setup.py
+++ b/docs/quick_tour/sessions/setup.py
@@ -17,8 +17,8 @@ requires = [
]
tests_require = [
- 'WebTest >= 1.3.1', # py3 compat
- 'pytest>=3.7.4',
+ 'WebTest',
+ 'pytest',
'pytest-cov',
]
diff --git a/docs/quick_tour/sqla_demo/setup.py b/docs/quick_tour/sqla_demo/setup.py
index 76cd518ca..28a8e0815 100644
--- a/docs/quick_tour/sqla_demo/setup.py
+++ b/docs/quick_tour/sqla_demo/setup.py
@@ -23,8 +23,8 @@ requires = [
]
tests_require = [
- 'WebTest >= 1.3.1', # py3 compat
- 'pytest>=3.7.4',
+ 'WebTest',
+ 'pytest',
'pytest-cov',
]
diff --git a/docs/quick_tour/sqla_demo/sqla_demo/models/meta.py b/docs/quick_tour/sqla_demo/sqla_demo/models/meta.py
index 02285b3ff..d659c7857 100644
--- a/docs/quick_tour/sqla_demo/sqla_demo/models/meta.py
+++ b/docs/quick_tour/sqla_demo/sqla_demo/models/meta.py
@@ -3,7 +3,7 @@ from sqlalchemy.schema import MetaData
# Recommended naming convention used by Alembic, as various different database
# providers will autogenerate vastly different names making migrations more
-# difficult. See: http://alembic.zzzcomputing.com/en/latest/naming.html
+# difficult. See: https://alembic.sqlalchemy.org/en/latest/naming.html
NAMING_CONVENTION = {
"ix": "ix_%(column_0_label)s",
"uq": "uq_%(table_name)s_%(column_0_name)s",
diff --git a/docs/quick_tour/sqla_demo/sqla_demo/static/theme.css b/docs/quick_tour/sqla_demo/sqla_demo/static/theme.css
index 0f4b1a4d4..a70ee557a 100644
--- a/docs/quick_tour/sqla_demo/sqla_demo/static/theme.css
+++ b/docs/quick_tour/sqla_demo/sqla_demo/static/theme.css
@@ -17,6 +17,9 @@ h6 {
p {
font-weight: 300;
}
+button, input, optgroup, select, textarea {
+ color: black;
+}
.font-normal {
font-weight: 400;
}
diff --git a/docs/quick_tour/views/views.py b/docs/quick_tour/views/views.py
index 95a2b60ca..ffbe1d893 100644
--- a/docs/quick_tour/views/views.py
+++ b/docs/quick_tour/views/views.py
@@ -1,4 +1,4 @@
-from pyramid.compat import escape
+from html import escape
from pyramid.httpexceptions import HTTPFound
from pyramid.response import Response
@@ -16,7 +16,7 @@ def home_view(request):
def hello_view(request):
name = request.params.get('name', 'No Name')
body = '<p>Hi %s, this <a href="/goto">redirects</a></p>'
# pyramid.compat.escape to prevent Cross-Site Scripting (XSS) [CWE 79]
return Response(body % escape(name))
@@ -16,7 +16,7 @@ def home_view(request):
name = request.params.get('name', 'No Name')
body = '<p>Hi %s, this <a href="/goto">redirects</a></p>'
- # pyramid.compat.escape to prevent Cross-Site Scripting (XSS) [CWE 79]
+ # Python html.escape to prevent Cross-Site Scripting (XSS) [CWE 79]
return Response(body % escape(name))